@@ -2,7 +2,7 @@
 """Host representation of evergreen."""
 from __future__ import absolute_import
 
-from typing import Any, Dict, TYPE_CHECKING
+from typing import TYPE_CHECKING, Any, Dict
 
 from evergreen.base import _BaseEvergreenObject, evg_attrib, evg_datetime_attrib
 
